@@ -37,6 +37,7 @@ struct _SunOneConnectionPrivate {
 
 	char *server_uri;
 	char *user;
+	char *uid;
 	char *password;
 	char *wcap_session_id;
 	char *wcap_version;
@@ -669,6 +670,7 @@ sunone_login (SunOneConnection *connection, gboolean refresh)
 	SunOneConnectionPrivate *priv = connection->priv;
 	SoupUri *login_uri;
 	SoupMessage *msg;
+	icalcomponent *icalcomp;
 	guint error_code = SOUP_STATUS_CANT_CONNECT;
 	char *encode_password = NULL;
 	
@@ -705,9 +707,34 @@ sunone_login (SunOneConnection *connection, gboolean refresh)
 			priv->is_open = TRUE;
 		}
 	}
-
+	/* parse the returned data */
+	icalcomp = sunone_util_icalparser_parse_string (msg->response.body, msg->response.length);
 	g_object_unref (msg);
 	soup_uri_free (login_uri);
+	if (icalcomp) {
+		icalproperty *icalprop =
+			icalcomponent_get_first_property (icalcomp, ICAL_X_PROPERTY);
+
+		while (icalprop) {
+			const char *x_name, *x_val;
+
+			x_name = icalproperty_get_x_name (icalprop);
+			x_val = icalproperty_get_x (icalprop);
+			/*
+			 * if user id is different from user name,
+			 * we have to remember user id and compare
+			 * it with primary owner of the folder to decide
+			 * if user is the owner of the folder.
+			 */
+			if (!strcmp (x_name, "X-NSCP-WCAP-USER-ID") &&
+				priv->user && x_val && strcmp (priv->user, x_val)) {
+				priv->uid = g_strdup (x_val);
+				fprintf (stderr, "uid:%s\n", x_val);
+			}
+			icalprop = icalcomponent_get_next_property (icalcomp, ICAL_X_PROPERTY);
+		}	
+		icalcomponent_free (icalcomp);
+	}
 
 	return error_code;
 }
@@ -800,6 +827,10 @@ sunone_connection_dispose (GObject *object)
 			g_free (priv->user);
 			priv->user = NULL;
 		}
+		if (priv->uid) {
+			g_free (priv->uid);
+			priv->uid = NULL;
+		}
 		if (priv->password) {
 			g_free (priv->password);
 			priv->password = NULL;
@@ -1009,6 +1040,15 @@ sunone_connection_get_user(SunOneConnection *connection)
 	return (const char *)priv->user;
 }
 
+const char *
+sunone_connection_get_uid(SunOneConnection *connection)
+{
+	SunOneConnectionPrivate *priv = connection->priv;
+
+	g_return_val_if_fail (IS_SUNONE_CONNECTION (connection), NULL);
+	return (const char *)priv->uid;
+}
+
 void
 sunone_connection_set_user (SunOneConnection *connection, const char *user)
 {
