@@ -28,6 +28,9 @@ sunone_util_icalparser_parse_string (const char *str, int len)
     icalcomponent *ical;
     char *string;
 
+	if (!str)
+		return NULL;
+
     string = g_strndup (str, len);
     ical = icalparser_parse_string (string);
     g_free (string);
@@ -186,6 +189,9 @@ sunone_util_has_permissions (SunOneCalendarProperties *props, const char *user,
 	g_return_val_if_fail (props != NULL, FALSE);
 	g_return_val_if_fail (props->primary_owner != NULL, FALSE);
 	
+	if (!user)
+		return FALSE;
+
 	/* if we're the primary owner, we can do whatever */
 	if (!strcasecmp (props->primary_owner, user))
 		return TRUE;
